import{C as n,A as t}from"./CollapsePanel.a5b374bc.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="13a7b8db-0c77-4a7c-9a5c-ec3544beb636",e._sentryDebugIdIdentifier="sentry-dbid-13a7b8db-0c77-4a7c-9a5c-ec3544beb636")}catch{}})();n.Panel=t;n.install=function(e){return e.component(n.name,n),e.component(t.name,t),e};
//# sourceMappingURL=index.47cea170.js.map
