import"./outputWidgets.f120b477.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="ed2c2871-ee17-4544-96c7-1af44f1e921e",e._sentryDebugIdIdentifier="sentry-dbid-ed2c2871-ee17-4544-96c7-1af44f1e921e")}catch{}})();const d=e=>{try{return new URL(e),!0}catch{return!1}};export{d as i};
//# sourceMappingURL=url.8af07297.js.map
