import{R as t}from"./Title.3dc4e32d.js";import{F as n}from"./outputWidgets.f120b477.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="4bd1793e-f0a6-4398-b26b-9d1518b0d30d",e._sentryDebugIdIdentifier="sentry-dbid-4bd1793e-f0a6-4398-b26b-9d1518b0d30d")}catch{}})();const b=n(t);export{b as A};
//# sourceMappingURL=index.3801d49d.js.map
