import"./outputWidgets.f120b477.js";(function(){try{var x=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(x._sentryDebugIds=x._sentryDebugIds||{},x._sentryDebugIds[e]="abb44945-a82a-4fd7-93e8-9b4a0a743794",x._sentryDebugIdIdentifier="sentry-dbid-abb44945-a82a-4fd7-93e8-9b4a0a743794")}catch{}})();const r=()=>"xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx".replace(/[xy]/g,function(x){const e=Math.random()*16|0;return(x=="x"?e:e&3|8).toString(16)}),a=()=>Math.random().toString(36).slice(2);export{a as r,r as u};
//# sourceMappingURL=uuid.c40ca677.js.map
