import{d as b,ez as y,J as h,b as g,c as w,u as _}from"./outputWidgets.f120b477.js";import{e as C,a as F,b as k}from"./icons.c367c256.js";import{a as x}from"./asyncComputed.5ccd4614.js";import{F as d}from"./forms.bee52afe.js";import{C as v}from"./CrudView.87b341af.js";import{a as D}from"./ant-design.13a5e655.js";import"./activeRecord.d87d7ef2.js";import"./pubsub.4681462f.js";import"./index.3ab4f365.js";import"./Title.3dc4e32d.js";import"./Form.ec892c10.js";import"./router.e3ecb487.js";import"./index.5818bfb2.js";import"./url.8af07297.js";import"./index.b96fbbd8.js";import"./index.3801d49d.js";import"./index.de46e6db.js";import"./index.54e8798a.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[r]="a76a5d2b-1d5c-4dc4-9e0c-ab032a3c308b",a._sentryDebugIdIdentifier="sentry-dbid-a76a5d2b-1d5c-4dc4-9e0c-ab032a3c308b")}catch{}})();const q=b({__name:"Forms",setup(a){const r=y(),{loading:s,result:n,refetch:c}=x(()=>d.list()),m=({key:e})=>r.push({path:`/_editor/form/${encodeURIComponent(e)}`}),l=async({key:e})=>{var o,t;await((t=(o=n.value)==null?void 0:o.find(i=>i.path===e))==null?void 0:t.duplicate()),c()},p=async()=>{const e=await d.create();m({key:e.path})},u=async({key:e})=>{var o,t;await D("Are you sure you want to delete this form?")&&(await((t=(o=n.value)==null?void 0:o.find(i=>i.path===e))==null?void 0:t.delete()),c())},f=h(()=>{var e,o;return{columns:[{name:"Form Name"},{name:"Path"},{name:"Actions",align:"right"}],rows:(o=(e=n.value)==null?void 0:e.map(t=>({key:t.path,cells:[{text:t.title,link:`/_editor/form/${encodeURIComponent(t.path)}`},{text:t.path},{text:"",actions:[{icon:C,label:"Edit Form",onClick:m},{icon:F,label:"Duplicate",onClick:l},{icon:k,label:"Delete",onClick:u,dangerous:!0}]}]})))!=null?o:[]}});return(e,o)=>(g(),w(v,{loading:_(s),title:"Dynamic Python forms",description:"Create forms with advanced logic, easy integrations and custom branding.","create-button-text":"Create Form","empty-title":"No forms here yet","video-url":"https://www.youtube.com/embed/p6xf8PxL2Yg",table:f.value,"entity-name":"Form",onCreate:p},null,8,["loading","table"]))}});export{q as default};
//# sourceMappingURL=Forms.9c628d5e.js.map
