import{S as p}from"./Sidebar.a8b3da86.js";import{_ as c}from"./Navbar.vue_vue_type_script_setup_true_lang.e49d6f27.js";import{G as d,H as l,I as u}from"./icons.c367c256.js";import{d as b,eA as f,J as g,a as _,b as y,c as v,w as t,f as r}from"./outputWidgets.f120b477.js";import{a as w}from"./asyncComputed.5ccd4614.js";import"./router.e3ecb487.js";import{O as z}from"./organization.70da67ff.js";import"./index.81859a03.js";import{B as h}from"./BaseLayout.90c0229e.js";import"./Tooltip.dcb77c4c.js";import"./logo.084e5d7c.js";import"./index.3ab4f365.js";import"./Title.3dc4e32d.js";import"./index.54e8798a.js";import"./index.2ac0b4db.js";import"./index.5818bfb2.js";import"./gateway.a36b7b3a.js";import"./activeRecord.d87d7ef2.js";import"./pubsub.4681462f.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="b0d53c54-2b27-479c-a53a-31d48ee08680",e._sentryDebugIdIdentifier="sentry-dbid-b0d53c54-2b27-479c-a53a-31d48ee08680")}catch{}})();const q=b({__name:"Organization",setup(e){const n=f().params.organizationId,{result:a}=w(()=>z.get(n)),i=g(()=>a.value?[{label:"My organizations",path:"/organizations"},{label:a.value.name,path:`/organizations/${a.value.id}`}]:void 0),s=[{name:"Organization",items:[{name:"Projects",icon:d,path:"projects"},{name:"Members",icon:l,path:"members"},{name:"Billing",icon:u,path:"billing",unavailable:!0}]}];return(I,B)=>{const m=_("router-view");return y(),v(h,null,{navbar:t(()=>[r(c,{breadcrumb:i.value},null,8,["breadcrumb"])]),sidebar:t(()=>[r(p,{class:"sidebar",sections:s})]),content:t(()=>[r(m)]),_:1})}}});export{q as default};
//# sourceMappingURL=Organization.362639ae.js.map
