import{_ as I}from"./logo.084e5d7c.js";import{x as B,b as s,eu as y,eD as C,eE as w,e as h,d as k,ez as L,a as D,u as e,c,bF as S,w as t,f as o,aJ as l,eC as d,c4 as f,cI as N,t as V,eB as E,e_ as R,bg as T,ew as F}from"./outputWidgets.f120b477.js";import{a as b}from"./router.e3ecb487.js";import{a as P}from"./asyncComputed.5ccd4614.js";import{a as $}from"./index.3ab4f365.js";import{A as g}from"./index.54e8798a.js";import{A as j,B as z,a as H,c as J}from"./index.2ac0b4db.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[r]="313c51ef-8558-457b-bc51-3515afc84ac4",a._sentryDebugIdIdentifier="sentry-dbid-313c51ef-8558-457b-bc51-3515afc84ac4")}catch{}})();const M={},v=a=>(C("data-v-439be421"),a=a(),w(),a),U={class:"logo"},q=v(()=>h("img",{class:"logo-img",src:I,alt:"Abstra cloud logo"},null,-1)),G=v(()=>h("span",null,"Abstra Cloud",-1)),K=[q,G];function O(a,r){return s(),y("div",U,K)}const Q=B(M,[["render",O],["__scopeId","data-v-439be421"]]),W=k({__name:"LoginBlock",setup(a){function r(p){const m=p.split("@")[0];return V.exports.kebabCase(m).toUpperCase().split("-").slice(0,2).map(i=>i[0]).join("")}const u=L(),{result:n,loading:_,refetch:x}=P(async()=>b.getAuthor());function A(){b.removeAuthor(),x(),u.push({name:"login"})}return(p,m)=>{const i=D("router-link");return e(_)?(s(),c(e(S),{key:0})):e(n)?(s(),c(e(N),{key:1,placement:"bottomRight"},{content:t(()=>[o(e(g),{direction:"vertical"},{default:t(()=>[o(e($),null,{default:t(()=>[l(d(e(n).claims.email),1)]),_:1}),o(e(f),{onClick:A},{default:t(()=>[l("Logout")]),_:1})]),_:1})]),default:t(()=>[o(e(g),{align:"center",style:{cursor:"pointer"}},{default:t(()=>[o(e(j),null,{default:t(()=>[l(d(r(e(n).claims.email)),1)]),_:1})]),_:1})]),_:1})):(s(),c(e(f),{key:2},{default:t(()=>[o(i,{to:"/login"},{default:t(()=>[l("Login")]),_:1})]),_:1}))}}}),re=k({__name:"Navbar",props:{breadcrumb:{}},setup(a){return(r,u)=>(s(),c(e(J),{style:{padding:"5px 10px"}},{breadcrumb:t(()=>[r.breadcrumb?(s(),c(e(z),{key:0},{default:t(()=>[(s(!0),y(T,null,E(r.breadcrumb,(n,_)=>(s(),c(e(H),{key:_},{default:t(()=>[o(e(R),{to:n.path},{default:t(()=>[l(d(n.label),1)]),_:2},1032,["to"])]),_:2},1024))),128))]),_:1})):F("",!0)]),title:t(()=>[o(Q)]),extra:t(()=>[o(W)]),_:1}))}});export{re as _};
//# sourceMappingURL=Navbar.vue_vue_type_script_setup_true_lang.e49d6f27.js.map
