import{x as o,a,b as i,c,g as d,h as p,_,i as u,T as f,j as l,P as h,C as m,M as y,s as b,k as s,l as g,m as v,n as w,p as I}from"./outputWidgets.f120b477.js";import{u as k}from"./index.662a67e5.js";import"./pubsub.4681462f.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="3c0bfdc5-750c-4168-8ba9-d38f6f770e6f",e._sentryDebugIdIdentifier="sentry-dbid-3c0bfdc5-750c-4168-8ba9-d38f6f770e6f")}catch{}})();const x={};function A(e,t){const r=a("router-view");return i(),c(r,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const D=o(x,[["render",A]]),n=d({history:p("/"),routes:[{path:"/:path(.*)*",name:"player",component:()=>_(()=>import("./Player.2e9bb105.js"),["assets/Player.2e9bb105.js","assets/index.5818bfb2.js","assets/outputWidgets.f120b477.js","assets/outputWidgets.f6e466ca.css","assets/uuid.c40ca677.js","assets/broker.1fed166c.js","assets/index.662a67e5.js","assets/pubsub.4681462f.js","assets/executeJs.92438dd0.js","assets/icons.c367c256.js","assets/CircularLoading.cab9f9eb.js","assets/CircularLoading.f81b57b4.css","assets/PlayerNavbar.a0c4b479.js","assets/PlayerNavbar.76a7eb2f.css","assets/Steps.114fc919.js","assets/Steps.998aa76d.css","assets/executeJs.ee59d5a5.css","assets/WidgetsFrame.54753673.js","assets/WidgetsFrame.0816a5f5.css","assets/ActionButton.vue_vue_type_script_setup_true_lang.3383c9db.js","assets/broker.1fe265d9.css","assets/DashPlayer.119c5628.js","assets/geometryUtils.5f5c4c2b.js","assets/DashPlayer.b0953bcd.css","assets/asyncComputed.5ccd4614.js","assets/Player.77337a17.css"])}],scrollBehavior(e){if(e.hash)return{el:e.hash}}});class P{static init(){setInterval(()=>fetch("/_version"),20*1e3)}}(async()=>{await k();const e=u({render:()=>g(D)});f.init(),l(e,n),P.init(),e.use(n),e.use(h),e.mount("#app"),e.component("VSelect",m),e.component("Markdown",y),e.component("Message",b),s(e,v),s(e,w),s(e,I)})();
//# sourceMappingURL=player.8d857b3b.js.map
