import"./outputWidgets.f120b477.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="577b4264-c884-4427-86a2-e175ac9fb102",e._sentryDebugIdIdentifier="sentry-dbid-577b4264-c884-4427-86a2-e175ac9fb102")}catch{}})();function a(e){return e.charAt(0).toUpperCase()+e.slice(1)}function c(e,r){const n=e.toLocaleLowerCase().replace(/[^a-z0-9]/g,"_").replace(/_+/g,"_");return r?n:n.replace(/_$/,"")}export{a as c,c as n};
//# sourceMappingURL=string.c4e71dd1.js.map
