import{d,eA as b,J as m,a as g,b as f,c as v,w as i,f as s}from"./outputWidgets.f120b477.js";import{B as _}from"./BaseLayout.90c0229e.js";import{a as h}from"./asyncComputed.5ccd4614.js";import{P as y}from"./project.594dcbc1.js";import"./router.e3ecb487.js";import{O as z}from"./organization.70da67ff.js";import"./index.81859a03.js";import{_ as j}from"./Navbar.vue_vue_type_script_setup_true_lang.e49d6f27.js";import{S as I}from"./Sidebar.a8b3da86.js";import{k as w,J as k,K as B,L as P,M as $,N as C,O as M,G as x,H as D,I as L}from"./icons.c367c256.js";import"./gateway.a36b7b3a.js";import"./activeRecord.d87d7ef2.js";import"./pubsub.4681462f.js";import"./Title.3dc4e32d.js";import"./index.5818bfb2.js";import"./logo.084e5d7c.js";import"./index.3ab4f365.js";import"./index.54e8798a.js";import"./index.2ac0b4db.js";import"./Tooltip.dcb77c4c.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="c27bca64-74a1-4d9d-a7c5-41f9bf4e11cc",o._sentryDebugIdIdentifier="sentry-dbid-c27bca64-74a1-4d9d-a7c5-41f9bf4e11cc")}catch{}})();const aa=d({__name:"Project",setup(o){const c=b().params.projectId,{result:a}=h(()=>y.get(c).then(async e=>{const t=await z.get(e.organizationId);return{project:e,organization:t}})),l=m(()=>{var e,t,n,p;return((e=a.value)==null?void 0:e.organization)&&a.value.project?[{label:"My organizations",path:"/organizations"},{label:(n=(t=a.value)==null?void 0:t.organization)==null?void 0:n.name,path:`/organizations/${(p=a.value)==null?void 0:p.organization.id}`},{label:a.value.project.name,path:`/projects/${a.value.project.id}`}]:void 0}),u=m(()=>{var e;return(e=a.value)!=null&&e.project?[{name:"Project",items:[{name:"Builds",path:"builds",icon:w},{name:"Connectors",path:"connectors",icon:k},{name:"Tables",path:"tables",icon:B},{name:"API Keys",path:"api-keys",icon:P},{name:"Env Vars",path:"env-vars",icon:$},{name:"Logs",icon:C,path:"logs",beta:!0},{name:"Settings",icon:M,path:"settings"}]},{name:"Organization",items:[{name:"Projects",icon:x,path:`/organizations/${a.value.project.organizationId}/projects`},{name:"Members",icon:D,path:`/organizations/${a.value.project.organizationId}/members`},{name:"Billing",icon:L,path:`/organizations/${a.value.project.organizationId}/billing`,unavailable:!0}]}]:[]});return(e,t)=>{const n=g("router-view");return f(),v(_,null,{content:i(()=>[s(n)]),navbar:i(()=>[s(j,{class:"nav",breadcrumb:l.value},null,8,["breadcrumb"])]),sidebar:i(()=>[s(I,{class:"sidebar",sections:u.value},null,8,["sections"])]),_:1})}}});export{aa as default};
//# sourceMappingURL=Project.e55415b1.js.map
