import{cG as r}from"./outputWidgets.f120b477.js";(function(){try{var d=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(d._sentryDebugIds=d._sentryDebugIds||{},d._sentryDebugIds[e]="52d0d3af-56f2-4dc0-82d8-5dfd460a56ce",d._sentryDebugIdIdentifier="sentry-dbid-52d0d3af-56f2-4dc0-82d8-5dfd460a56ce")}catch{}})();const o=(d,e)=>{r.error({message:d,description:e})};export{o as p};
//# sourceMappingURL=popupNotifcation.5f5cb1af.js.map
