import{d as u,eA as b,J as f,b as y,c as g,u as _}from"./outputWidgets.f120b477.js";import{a as w}from"./asyncComputed.5ccd4614.js";import"./router.e3ecb487.js";import{M as n}from"./member.8175ed47.js";import"./index.81859a03.js";import{C as I}from"./CrudView.87b341af.js";import"./Title.3dc4e32d.js";import"./index.5818bfb2.js";import"./gateway.a36b7b3a.js";import"./activeRecord.d87d7ef2.js";import"./pubsub.4681462f.js";import"./icons.c367c256.js";import"./index.3ab4f365.js";import"./Form.ec892c10.js";import"./url.8af07297.js";import"./index.b96fbbd8.js";import"./index.3801d49d.js";import"./index.de46e6db.js";import"./index.54e8798a.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="58e02705-af1e-4c2c-9789-784cb9054290",e._sentryDebugIdIdentifier="sentry-dbid-58e02705-af1e-4c2c-9789-784cb9054290")}catch{}})();const F=u({__name:"Members",setup(e){const r=b().params.organizationId,m=[{key:"email",label:"Email"}],s=async t=>{await n.create(r,t.email),p()},{loading:l,result:c,refetch:p}=w(()=>n.list(r)),d=f(()=>{var t,a;return{columns:[{name:"Email"},{name:"Role"}],rows:(a=(t=c.value)==null?void 0:t.map(i=>({key:i.email,cells:[{text:i.email},{text:i.role}]})))!=null?a:[]}});return(t,a)=>(y(),g(I,{"entity-name":"members",loading:_(l),title:"Organization members",description:"List all organization members.","empty-title":"No members yet",table:d.value,"create-button-text":"Add members",fields:m,onCreate:s},null,8,["loading","table"]))}});export{F as default};
//# sourceMappingURL=Members.aa6a2c44.js.map
