import{d as g,ez as v,eA as b,r as k,b as r,c as s,w as a,u as e,f as u,ew as n}from"./outputWidgets.f120b477.js";import{S as h,L as w}from"./SmartConsole.8f4d2d35.js";import{a as x}from"./asyncComputed.5ccd4614.js";import{H as B}from"./hooks.a815f30a.js";import{_ as C}from"./SaveButton.vue_vue_type_script_setup_true_lang.4077bfd8.js";import{_ as H}from"./DocsButton.vue_vue_type_script_setup_true_lang.a4b61028.js";import{B as I}from"./BaseLayout.90c0229e.js";import{_ as S,a as T}from"./HookSettings.vue_vue_type_script_setup_true_lang.a4a9552a.js";import{c as A}from"./index.2ac0b4db.js";import{A as _,T as D}from"./TabPane.5ad7b86d.js";import"./forms.bee52afe.js";import"./activeRecord.d87d7ef2.js";import"./pubsub.4681462f.js";import"./dashes.4d7eaf1c.js";import"./index.5818bfb2.js";import"./jobs.ec327d00.js";import"./workspaces.901e1f01.js";import"./url.8af07297.js";import"./icons.c367c256.js";import"./Title.3dc4e32d.js";import"./index.3801d49d.js";import"./uuid.c40ca677.js";import"./ant-design.13a5e655.js";import"./StageRunSelector.vue_vue_type_script_setup_true_lang.7aeb7be4.js";import"./RunButton.vue_vue_type_script_setup_true_lang.c672b852.js";import"./index.97802764.js";import"./index.de46e6db.js";import"./CollapsePanel.a5b374bc.js";import"./index.54e8798a.js";import"./index.0f18085a.js";import"./index.b96fbbd8.js";import"./Form.ec892c10.js";(function(){try{var i=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},m=new Error().stack;m&&(i._sentryDebugIds=i._sentryDebugIds||{},i._sentryDebugIds[m]="2dd0e175-ed96-4922-99c3-8a0c613f14b1",i._sentryDebugIdIdentifier="sentry-dbid-2dd0e175-ed96-4922-99c3-8a0c613f14b1")}catch{}})();const le=g({__name:"HookEditor",setup(i){const m=v(),l=b(),c=k(null),o=k("test");function y(){m.push({name:"hooks"})}const{result:t}=x(()=>B.get(l.params.hookPath)),f=w.create();return(R,d)=>(r(),s(I,null,{navbar:a(()=>[e(t)?(r(),s(e(A),{key:0,title:e(t).title,style:{padding:"5px 10px"},onBack:y},{footer:a(()=>[u(e(D),{"active-key":o.value,"onUpdate:activeKey":d[0]||(d[0]=p=>o.value=p)},{default:a(()=>[u(e(_),{key:"test",tab:"Test"}),u(e(_),{key:"settings",tab:"Settings"})]),_:1},8,["active-key"])]),extra:a(()=>[u(H,{path:"hooks"}),o.value==="settings"?(r(),s(C,{key:0,model:e(t)},null,8,["model"])):n("",!0)]),_:1},8,["title"])):n("",!0)]),content:a(()=>[e(t)&&o.value==="test"?(r(),s(S,{key:0,ref_key:"tester",ref:c,hook:e(t),"log-service":e(f)},null,8,["hook","log-service"])):n("",!0),e(t)&&o.value==="settings"?(r(),s(T,{key:1,hook:e(t)},null,8,["hook"])):n("",!0)]),footer:a(()=>{var p;return[e(t)&&o.value==="test"?(r(),s(h,{key:0,runtime:"forms","log-service":e(f),onRestart:(p=c.value)==null?void 0:p.runHook},null,8,["log-service","onRestart"])):n("",!0)]}),_:1}))}});export{le as default};
//# sourceMappingURL=HookEditor.57b8fff0.js.map
