import{d as g,ez as v,eA as k,r as b,b as r,c as s,w as a,u as e,f as p,ew as n}from"./outputWidgets.f120b477.js";import{S as w,L as j}from"./SmartConsole.8f4d2d35.js";import{a as x}from"./asyncComputed.5ccd4614.js";import{J as I}from"./jobs.ec327d00.js";import{_ as B}from"./SaveButton.vue_vue_type_script_setup_true_lang.4077bfd8.js";import{_ as C}from"./DocsButton.vue_vue_type_script_setup_true_lang.a4b61028.js";import{B as S}from"./BaseLayout.90c0229e.js";import{_ as T,a as A}from"./JobSettings.vue_vue_type_script_setup_true_lang.e5269248.js";import{c as D}from"./index.2ac0b4db.js";import{A as _,T as R}from"./TabPane.5ad7b86d.js";import"./forms.bee52afe.js";import"./activeRecord.d87d7ef2.js";import"./pubsub.4681462f.js";import"./dashes.4d7eaf1c.js";import"./index.5818bfb2.js";import"./hooks.a815f30a.js";import"./workspaces.901e1f01.js";import"./url.8af07297.js";import"./icons.c367c256.js";import"./Title.3dc4e32d.js";import"./index.3801d49d.js";import"./uuid.c40ca677.js";import"./ant-design.13a5e655.js";import"./RunButton.vue_vue_type_script_setup_true_lang.c672b852.js";import"./index.bc6db419.js";import"./index.b96fbbd8.js";import"./dayjs.ec7f7e5e.js";import"./Form.ec892c10.js";import"./index.54e8798a.js";(function(){try{var i=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},m=new Error().stack;m&&(i._sentryDebugIds=i._sentryDebugIds||{},i._sentryDebugIds[m]="3ce277b1-c2ba-4fcd-8f41-5f9fa0d931b9",i._sentryDebugIdIdentifier="sentry-dbid-3ce277b1-c2ba-4fcd-8f41-5f9fa0d931b9")}catch{}})();const me=g({__name:"JobEditor",setup(i){const m=v(),u=k(),c=b(null),o=b("test");function y(){m.push({name:"jobs"})}const{result:t}=x(()=>I.get(u.params.jobId)),l=j.create();return($,d)=>(r(),s(S,null,{navbar:a(()=>[e(t)?(r(),s(e(D),{key:0,title:e(t).title,style:{padding:"5px 10px"},onBack:y},{footer:a(()=>[p(e(R),{"active-key":o.value,"onUpdate:activeKey":d[0]||(d[0]=f=>o.value=f)},{default:a(()=>[p(e(_),{key:"test",tab:"Test"}),p(e(_),{key:"settings",tab:"Settings"})]),_:1},8,["active-key"])]),extra:a(()=>[p(C),o.value==="settings"?(r(),s(B,{key:0,model:e(t)},null,8,["model"])):n("",!0)]),_:1},8,["title"])):n("",!0)]),content:a(()=>[e(t)&&o.value==="test"?(r(),s(T,{key:0,ref_key:"tester",ref:c,job:e(t),"log-service":e(l)},null,8,["job","log-service"])):n("",!0),e(t)&&o.value==="settings"?(r(),s(A,{key:1,job:e(t)},null,8,["job"])):n("",!0)]),footer:a(()=>{var f;return[e(t)&&o.value==="test"?(r(),s(w,{key:0,runtime:"forms","log-service":e(l),onRestart:(f=c.value)==null?void 0:f.test},null,8,["log-service","onRestart"])):n("",!0)]}),_:1}))}});export{me as default};
//# sourceMappingURL=JobEditor.2c978c47.js.map
