import{d as y,r as f,J as x,b as g,eu as v,aD as b,e as d,eC as m,ev as D,x as w}from"./outputWidgets.f120b477.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="f88564f2-01e8-4d87-977a-f2efdf778a8c",t._sentryDebugIdIdentifier="sentry-dbid-f88564f2-01e8-4d87-977a-f2efdf778a8c")}catch{}})();const B={class:"text"},k=y({__name:"Tooltip",props:{text:{type:String,required:!0},left:{type:Number},top:{type:Number},fixed:{type:Boolean,default:!1}},setup(t){const e=t,s=f(Date.now()),p=()=>{s.value=Date.now()},n=f(null),c=()=>{var r,l,i;const o=(r=n.value)==null?void 0:r.getBoundingClientRect();if(!o)return{};const{x:a,y:_}=o;return s.value,{position:"fixed",top:`${_+((l=e.top)!=null?l:0)}px`,left:`${a+((i=e.left)!=null?i:0)}px`}},u=x(()=>{var o;return e.fixed?c():{left:`${(o=e.left)!=null?o:-14}px`,...e.top?{top:`${e.top}px`}:{}}});return(o,a)=>(g(),v("div",{ref_key:"tooltipBox",ref:n,class:"tooltip-box",onMouseenter:p},[b(o.$slots,"default",{},void 0,!0),d("div",{class:"tooltip",style:D(u.value)},[d("span",B,m(t.text),1)],4)],544))}});const h=w(k,[["__scopeId","data-v-74636348"]]);export{h as T};
//# sourceMappingURL=Tooltip.dcb77c4c.js.map
