import{W as s}from"./outputWidgets.f120b477.js";import{c,d as i}from"./index.bc6db419.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="0811de0d-6429-4aa4-9d29-e0e0e8b0ba2c",e._sentryDebugIdIdentifier="sentry-dbid-0811de0d-6429-4aa4-9d29-e0e0e8b0ba2c")}catch{}})();const{DatePicker:n,WeekPicker:r,MonthPicker:t,YearPicker:m,TimePicker:f,QuarterPicker:a,RangePicker:o}=c(i),y=s(n,{WeekPicker:r,MonthPicker:t,YearPicker:m,RangePicker:o,TimePicker:f,QuarterPicker:a,install:e=>(e.component(n.name,n),e.component(o.name,o),e.component(t.name,t),e.component(r.name,r),e.component(a.name,a),e)});export{y as D,t as M,a as Q,o as R,r as W};
//# sourceMappingURL=dayjs.4982b6e6.js.map
