import{v as s}from"./icons.c367c256.js";import{d as r,a as c,b as d,eu as i,f as _,u as f,aJ as l,x as u}from"./outputWidgets.f120b477.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="2d986ad1-e310-4636-91ba-42f982bf1039",e._sentryDebugIdIdentifier="sentry-dbid-2d986ad1-e310-4636-91ba-42f982bf1039")}catch{}})();const p=r({__name:"BackButton",emits:["exitFullscreenPreview"],setup(e,{emit:t}){return(o,n)=>{const a=c("icon");return d(),i("button",{class:"back-btn",onClick:n[0]||(n[0]=b=>t("exitFullscreenPreview"))},[_(a,{class:"icon",path:f(s),width:"20",height:"20",fill:"#5A677A"},null,8,["path"]),l(" Editor ")])}}});const v=u(p,[["__scopeId","data-v-eaeb3a6e"]]);export{v as B};
//# sourceMappingURL=BackButton.05b6cb28.js.map
